==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QPropertyValueAddedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a value is added to a property</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html">Qt3DCore::QPropertyValueAddedChange</a></p>
 */
public class QPropertyValueAddedChange extends io.qt.qt3d.core.QStaticPropertyValueAddedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html#QPropertyValueAddedChange">Qt3DCore::QPropertyValueAddedChange::QPropertyValueAddedChange(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    public QPropertyValueAddedChange(io.qt.qt3d.core.@NonNull QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QPropertyValueAddedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html#addedValue">Qt3DCore::QPropertyValueAddedChange::addedValue()const</a></p>
     */
    @QtUninvokable
    public final java.lang.Object addedValue(){
        return addedValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object addedValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html#setAddedValue">Qt3DCore::QPropertyValueAddedChange::setAddedValue(QVariant)</a></p>
     */
    @QtUninvokable
    public final void setAddedValue(java.lang.Object value){
        setAddedValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @QtUninvokable
    private native void setAddedValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QPropertyValueAddedChange(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.19-sources.jar: io/qt/qt3d/core/QPropertyValueAddedChange.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>Used to notify when a value is added to a property</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html">Qt3DCore::QPropertyValueAddedChange</a></code></p>
 */
public class QPropertyValueAddedChange extends io.qt.qt3d.core.QStaticPropertyValueAddedChangeBase
{
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html#QPropertyValueAddedChange">Qt3DCore::QPropertyValueAddedChange::<wbr/>QPropertyValueAddedChange(Qt3DCore::QNodeId)</a></code></p>
     */
    public QPropertyValueAddedChange(io.qt.qt3d.core.@NonNull QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    private native static void initialize_native(QPropertyValueAddedChange instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html#addedValue">Qt3DCore::QPropertyValueAddedChange::<wbr/>addedValue()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.Object addedValue(){
        return addedValue_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.Object addedValue_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qpropertyvalueaddedchange.html#setAddedValue">Qt3DCore::QPropertyValueAddedChange::<wbr/>setAddedValue(QVariant)</a></code></p>
     */
    @QtUninvokable
    public final void setAddedValue(java.lang.Object value){
        setAddedValue_native_cref_QVariant(QtJambi_LibraryUtilities.internal.nativeId(this), value);
    }
    
    @QtUninvokable
    private native void setAddedValue_native_cref_QVariant(long __this__nativeId, java.lang.Object value);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QPropertyValueAddedChange(QPrivateConstructor p) { super(p); } 
    
}
